Function image_track::pad_sector
source · pub fn pad_sector(size: u64) -> u64Expand description
pad the byte size to sectors that will take place in the image
pub fn pad_sector(size: u64) -> u64pad the byte size to sectors that will take place in the image